@@ -11,6 +11,9 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *	When adding parameter macros here, remember to also update
+ *	their default values in the pars structure mpars in rwconf.c.
+ *
  * fmg 1/11/94 colors
  * fmg 2/15/94 macros
  * jl  04.09.97 conversion file
@@ -21,6 +24,8 @@
  * jl  05.04.98 added parameter P_MUL
  * jl  06.07.98 added parameter P_CONVCAP
  * jl  28.11.98 added parameter P_SHOWSPD
+ * jl  05.04.99 logging options P_LOGFNAME, P_LOGCONN and P_LOGXFER
+ * er  18-Apr.99 added parameter P_MULTILINE
  */
 
 #define PARS_VAL_LEN 64
@@ -71,70 +76,78 @@ extern struct macs mmacs[];
 #define P_BAUDRATE	mpars[28].value
 #define P_BITS		mpars[29].value
 #define P_PARITY	mpars[30].value
-#define P_KERMIT	mpars[31].value
-#define P_KERMALLOW	mpars[32].value
-#define P_KERMREAL	mpars[33].value
-#define P_COLUSAGE	mpars[34].value
-#define P_SCRIPTPROG	mpars[35].value
+#define P_STOPB		mpars[31].value
+#define P_KERMIT	mpars[32].value
+#define P_KERMALLOW	mpars[33].value
+#define P_KERMREAL	mpars[34].value
+#define P_COLUSAGE	mpars[35].value
+#define P_SCRIPTPROG	mpars[36].value
 /* The next entries must be kept in order */
-#define P_MINIT		mpars[36].value
-#define P_MRESET	mpars[37].value
-#define P_MDIALPRE	mpars[38].value
-#define P_MDIALSUF	mpars[39].value
-#define P_MDIALPRE2	mpars[40].value
-#define P_MDIALSUF2	mpars[41].value
-#define P_MDIALPRE3	mpars[42].value
-#define P_MDIALSUF3	mpars[43].value
-#define P_MCONNECT	mpars[44].value
-#define P_MNOCON1	mpars[45].value
-#define P_MNOCON2	mpars[46].value
-#define P_MNOCON3	mpars[47].value
-#define P_MNOCON4	mpars[48].value
-#define P_MHANGUP	mpars[49].value
-#define P_MDIALCAN	mpars[50].value
-#define P_MDIALTIME	mpars[51].value
-#define P_MRDELAY	mpars[52].value
-#define P_MRETRIES	mpars[53].value
+#define P_MINIT		mpars[37].value
+#define P_MRESET	mpars[38].value
+#define P_MDIALPRE	mpars[39].value
+#define P_MDIALSUF	mpars[40].value
+#define P_MDIALPRE2	mpars[41].value
+#define P_MDIALSUF2	mpars[42].value
+#define P_MDIALPRE3	mpars[43].value
+#define P_MDIALSUF3	mpars[44].value
+#define P_MCONNECT	mpars[45].value
+#define P_MNOCON1	mpars[46].value
+#define P_MNOCON2	mpars[47].value
+#define P_MNOCON3	mpars[48].value
+#define P_MNOCON4	mpars[49].value
+#define P_MHANGUP	mpars[50].value
+#define P_MDIALCAN	mpars[51].value
+#define P_MDIALTIME	mpars[52].value
+#define P_MRDELAY	mpars[53].value
+#define P_MRETRIES	mpars[54].value
 /* Yup, until here. */
-#define P_MDROPDTR	mpars[54].value
-#define P_MAUTOBAUD	mpars[55].value
-#define P_SHOWSPD	mpars[56].value
-#define P_UPDIR		mpars[57].value
-#define P_DOWNDIR	mpars[58].value
-#define P_SCRIPTDIR	mpars[59].value
-#define P_ESCAPE	mpars[60].value
-#define P_BACKSPACE	mpars[61].value
-#define P_STATLINE	mpars[62].value
-#define P_HASDCD	mpars[63].value
-#define P_HASRTS	mpars[64].value
-#define P_HASXON	mpars[65].value
-#define P_PAUTO		mpars[66].value
+#define P_MDROPDTR	mpars[55].value
+#define P_MAUTOBAUD	mpars[56].value
+#define P_SHOWSPD	mpars[57].value
+#define P_UPDIR		mpars[58].value
+#define P_DOWNDIR	mpars[59].value
+#define P_SCRIPTDIR	mpars[60].value
+#define P_ESCAPE	mpars[61].value
+#define P_BACKSPACE	mpars[62].value
+#define P_STATLINE	mpars[63].value
+#define P_HASDCD	mpars[64].value
+#define P_HASRTS	mpars[65].value
+#define P_HASXON	mpars[66].value
+#define P_PAUTO		mpars[67].value
 
 /* fmg colors - these are used in signaling when values have changed
                 so that the preferences saving function knows what to save */
 
-#define P_MFG           mpars[67].value
-#define P_MBG           mpars[68].value
-#define P_TFG           mpars[69].value
-#define P_TBG           mpars[70].value
-#define P_SFG           mpars[71].value
-#define P_SBG           mpars[72].value
+#define P_MFG           mpars[68].value
+#define P_MBG           mpars[69].value
+#define P_TFG           mpars[70].value
+#define P_TBG           mpars[71].value
+#define P_SFG           mpars[72].value
+#define P_SBG           mpars[73].value
 
 /* fmg  macros file name & entry used to signal when macros need to be saved */
 
-#define P_MACROS        mpars[73].value  /* macros save filename */
-#define P_MACCHG        mpars[74].value  /* macros changed flag */
-#define P_MACENAB	mpars[75].value	 /* macros enabled flag */
+#define P_MACROS        mpars[74].value  /* macros save filename */
+#define P_MACCHG        mpars[75].value  /* macros changed flag */
+#define P_MACENAB	mpars[76].value	 /* macros enabled flag */
 
-#define P_SOUND		mpars[76].value
-#define P_HISTSIZE      mpars[77].value  /* History buffer size */
+#define P_SOUND		mpars[77].value
+#define P_HISTSIZE      mpars[78].value  /* History buffer size */
 
-#define P_CONVF		mpars[78].value  /* Char.conversion table */
-#define P_CONVCAP	mpars[79].value  /* Use conversion on capture file */
+#define P_CONVF		mpars[79].value  /* Char.conversion table */
+#define P_CONVCAP	mpars[80].value  /* Use conversion on capture file */
+
+#define P_FSELW		mpars[81].value  /* Filename selection window */
+#define P_ASKDNDIR	mpars[82].value  /* Ask dir. for downloads or not */
+
+/* jl 4.1999 logfile options */
+#define P_LOGFNAME	mpars[83].value  /* Filename for the logfile */
+#define P_LOGCONN	mpars[84].value  /* Log connects and hangups */
+#define P_LOGXFER	mpars[85].value  /* Log file transfers */
+
+#define P_MULTILINE 	mpars[86].value  /* Multi-node untag  er 18-Apr-99 */
 
-#define P_FSELW		mpars[80].value  /* Filename selection window */
-#define P_ASKDNDIR	mpars[81].value  /* Ask dir. for downloads or not */
- 
 /* fmg - macros struct */
 
 #define P_MAC1          mmacs[0].value
