@@ -2,6 +2,8 @@
  * dial.c	Functions to dial, retry etc. Als contains the dialing
  *		directory code, _and_ the famous tu-di-di music.
  *
+ *		$Id: dial.c,v 1.2 1999/09/03 12:23:09 walker Exp $
+ *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
  *
@@ -17,7 +19,9 @@
  *   jl 26.01.98  last login date & time added to dialing window
  *   jl 16.04.98  start searching for dialing tags from the highlighted entry
  *   jl 12.06.98  save the old dialdir if it was an old version
- *
+ *   er 18-Apr-99 When calling a multiline BBS
+ *		  tagged entries with same name are untagged
+ *   jl 01.09.99  Move entry up/down in directory
  */
 
 #include "port.h"
@@ -95,6 +99,7 @@ struct dialent {
   char lasttime[9];	/* jl 22.06.97 */
   int  count;		/* jl 22.06.97 */
   char convfile[16];	/* jl 21.09.97 */
+  char stopb[2];	/* jl 07.01.2000 */
   struct dialent *next;
 };
 
@@ -218,15 +223,14 @@ void hangup()
 {
   WIN *w;
   int sec=1;
-  char buf[80];
   extern time_t old_online;
 
   w = mc_tell(_("Hanging up"));
 
   timer_update();
-  snprintf(buf, sizeof(buf),_("Hangup (%ld:%02ld:%02ld)"),
+  if (P_LOGCONN[0] == 'Y')
+    do_log(_("Hangup (%ld:%02ld:%02ld)"),
 	   online / 3600, (online / 60) % 60, online>0 ? online % 60 : 0);
-  do_log(buf);
   online = -1;
   old_online = -1;
 
@@ -246,7 +250,8 @@ void hangup()
   /* If we don't have DCD support fake DCD dropped */
   bogus_dcd = 0;
   wclose(w, 1);
-  time_status();
+
+  if (st) time_status();
 }
 
 /*
@@ -372,7 +377,7 @@ struct dialent **d2;
   struct tm *ptime;
   char buf[128];
   char modbuf[128];
-  char logline[128];
+  /*  char logline[128]; */
 
   timer_update(); /* Statusline may still show 'Online' / jl 16.08.97 */
   /* don't do anything if already online! jl 07.07.98 */
@@ -503,15 +508,15 @@ MainLoop:
 			/* Try to do auto-bauding */
 			if (sscanf(modbuf + strlen(P_MCONNECT), "%ld", &nb) == 1)
 				retst = nb;
+			linespd = retst;
 
 			/* Try to figure out if this system supports DCD */
 			f = m_getdcd(portfd);
 			bogus_dcd = 1;
 
-			/* jl 22.05.97, 22.09.97 */
-			snprintf(logline, sizeof(logline), "%s %s, %s",
-				modbuf, d->name, d->number);
-			do_log(logline);
+			/* jl 22.05.97, 22.09.97, 05.04.99 */
+			if (P_LOGCONN[0] == 'Y')
+			  do_log("%s %s, %s",modbuf, d->name, d->number);
 
 			ptime=localtime(&now);
 			sprintf(d->lastdate,"%4.4d%2.2d%2.2d",
@@ -521,10 +526,12 @@ MainLoop:
 				ptime->tm_hour,ptime->tm_min);
 			d->count ++;
 
+#ifdef _HAVE_MACROS
 			if (d->convfile[0]) {
 			  loadconv(d->convfile);    /* jl 21.09.97 */
 			  strcpy(P_CONVF, d->convfile);
 			}
+#endif
 
 			wlocate(dialwin, 1, 7);
 			if (d->script[0] == 0) {
@@ -556,9 +563,25 @@ MainLoop:
 
 			/* Un-tag this entry. */
 			d->flags &= ~FL_TAG;
+
 			/* store pointer to the entry that ANSWERED */
 			if (d2 != (struct dialent**)NULL)
 			  *d2 = d;	/* jl 23.09.97 */
+
+/* Here should placed code to untag phones with similar names */ 
+			if (P_MULTILINE[0] == 'Y') {
+			
+			  struct dialent *d3;
+			  	
+			  d3 = dialents;
+			  while (d3 != (struct dialent*)NULL) {
+			  	if (!strcmp(d3->name, d->name))
+			  		d3->flags &= ~FL_TAG;
+
+			  	d3 = d3->next;
+			  }				
+			}				/*  er 27-Apr-99 */
+
 			return(retst);
 		}
 		for(f = 0; f < 3; f++) {
@@ -637,6 +660,7 @@ static struct dialent *mkstdent()
   d->lasttime[0] = 0;
   d->count = 0;
   d->convfile[0] = 0;	/* jl 21.09.97 */
+  strcpy(d->stopb, "1");
   d->next = (struct dialent *)0;
 
   return(d);
@@ -651,12 +675,14 @@ struct dver *dv;	/* jl 21.09.97 */
   (void) fread((char *)d, dv->size, (size_t)1, fp);
 
   if (dv->size < sizeof(struct dialent)) {
-    d->convfile[0]=0;
     if (dv->size < offsetof(struct dialent, count) + sizeof(struct dialent *)){
       d->count = 0;
       d->lasttime[0] = 0;
       d->lastdate[0] = 0;
     }
+    if (dv->size < offsetof(struct dialent, stopb) + sizeof(struct dialent *))
+      d->convfile[0]=0;
+    strcpy(d->stopb, "1");
   }
 }
 
@@ -674,6 +700,8 @@ FILE *fp;
   d->lasttime[0]=0;
   d->count=0;
   d->convfile[0]=0;
+  d->stopb[0]='1';
+  d->stopb[1]=0;
 }
 
 /* Read version 2 of the dialing directory. */
@@ -690,6 +718,8 @@ FILE *fp;
   d->lasttime[0]=0;
   d->count=0;
   d->convfile[0]=0;
+  d->stopb[0]='1';
+  d->stopb[1]=0;
 }
 
 /* Read version 1 of the dialing directory. */
@@ -708,6 +738,8 @@ struct dialent *d;
   d->lasttime[0]=0;
   d->count=0;
   d->convfile[0]=0;
+  d->stopb[0]='1';
+  d->stopb[1]=0;
 }
 
 /* Read version 0 of the dialing directory. */
@@ -873,7 +905,8 @@ int readdialdir()
   if (dial_ver.size < sizeof(struct dialent)) {
     if (snprintf(copycmd,sizeof(copycmd),
 	     "cp %s %s.%hd",dfile,dfile,dial_ver.size) > 0) {
-      do_log(copycmd);
+      if (P_LOGFNAME[0] != 0)
+	do_log(copycmd);
       if (system(copycmd) == 0) {
 	snprintf(copycmd,sizeof(copycmd),
 		 _("Old dialdir copied as %s.%hd"),dfile,dial_ver.size);
@@ -996,8 +1029,8 @@ struct dialent *d;
 	d->flags & FL_DEL ? _("Delete") : _("Backspace"));
   wprintf(w, "%s %s\n", linewrap,
 	d->flags & FL_WRAP ? _("On") : _("Off"));
-  wprintf(w, "%s %s %s%s1\n", line_settings,
-  	d->baud, d->bits, d->parity);
+  wprintf(w, "%s %s %s%s%s\n", line_settings,
+  	d->baud, d->bits, d->parity, d->stopb);
   wprintf(w, "%s %s\n", conversion_table, d->convfile);
   wprintf(w, _("      Last dialed         : %s %s\n"),d->lastdate,d->lasttime);
   wprintf(w, _("      Times on            : %d"),d->count);
@@ -1078,9 +1111,10 @@ struct dialent *d;
 		wputs(w, d->flags & FL_WRAP ? _("On ") : _("Off"));
 		break;
   	case 'K':
-  		get_bbp(d->baud, d->bits, d->parity, 1);
+  		get_bbp(d->baud, d->bits, d->parity, d->stopb, 1);
   		wlocate(w, strlen (line_settings) + 1, 10);
-  		wprintf(w, "%s %s%s1  ", d->baud, d->bits, d->parity);
+  		wprintf(w, "%s %s%s%s  ",
+			d->baud, d->bits, d->parity, d->stopb);
   		break;
  	case 'L':	/* jl 21.09.97 */
 		wlocate(w, strlen (conversion_table) + 1, 11);
@@ -1093,10 +1127,12 @@ struct dialent *d;
 }
 
 static WIN *dsub;
-static char *what =  N_("  Dial    Find    Add     Edit   Remove  Manual ");
-/*                       123456789012345678901234567890123456789012345678
-			          1         2         3         4            */
+static char *what =  
+        N_("  Dial    Find    Add     Edit   Remove   moVe   Manual ");
+/*          12345678901234567890123456789012345678901234567890123456
+		     1         2         3         4         5       */
 static int dprev;
+#define DIALOPTS 7   /* Number of commands in vertical dial menu */
 
 /*
  * Highlight a choice in the horizontal menu.
@@ -1110,7 +1146,7 @@ int position_dialing_directory, k;
      with spaces... I only hope the translations are smart enough to
      figure this out... ;> */
 
-  int option_size = strlen (_(what)) / 6;
+  int option_size = strlen (_(what)) / DIALOPTS;
 
   if (k == dprev) return;
 
@@ -1161,6 +1197,80 @@ int top, cur;
   wflush();
 }
 
+/*
+ * Move an entry forward/back in the dial directory. jl 1.9.1999
+ */
+int move_entry(WIN *dialw, struct dialent *d, int cur, int *top)
+{
+  int ocur = cur,
+      quit = 0,
+      c = 0;
+  struct dialent *dtmp;
+
+  while (!quit) {
+
+    switch (c = wxgetch()) {
+    	case K_DN:
+    	case 'j':
+	  if (!(d->next))
+	    break;
+	  if (cur == 0) {   /* special case: move d from start to 2nd */
+	    dtmp = d->next;
+	    d->next = dtmp->next;
+	    dtmp->next = d;
+	    dialents = dtmp;
+	  } else {	    /* swap d with the next one in the list */
+	    dtmp = getno(cur - 1);
+	    dtmp->next = d->next;
+	    d->next = d->next->next;
+	    dtmp->next->next = d;
+	  }
+	  cur++;
+	  break;
+    	case K_UP:
+    	case 'k':
+	  if (cur == 0)
+	    break;
+	  if (cur == 1) { /* special case: move d to start of list */
+	    dtmp = dialents;
+	    dtmp->next = d-> next;
+	    d->next = dtmp;
+	    dialents = d;
+	  } else {	  /* swap d with the previous one in the list */
+	    dtmp = getno(cur - 2);
+	    dtmp->next->next = d-> next;
+	    d->next = dtmp->next;
+	    dtmp->next = d;
+	  }
+	  cur--;
+	  break;
+    	case '\033':
+    	case '\r':
+    	case '\n':
+	  quit = 1;
+	  break;
+    	default:
+	  break;
+    } /* end switch */
+
+    /* If the list order changed, redraw the directory window */
+    if (cur != ocur) {
+      /* First remove cursor bar from the old position */
+      wcurbar(dialw, ocur + 1 - *top, XA_NORMAL | stdattr);
+      if (cur < *top)
+	(*top)--;
+      else if (cur - *top > dialw->ys - 3)
+	(*top)++;
+      prdir(dialw, *top, *top);
+      wcurbar(dialw, cur + 1 - *top, XA_REVERSE | stdattr);
+      ocur = cur;
+    } /* end redraw condition */
+
+  }   /* end loop   */
+
+  return cur;
+}
+
 /* Little menu. */
 static char *d_yesno[] = { N_("   Yes  "), N_("   No   "), CNULL };
 
@@ -1176,6 +1286,7 @@ struct dialent *d;
   	strcpy(P_BAUDRATE, d->baud);
 	strcpy(P_PARITY, d->parity);
 	strcpy(P_BITS, d->bits);
+	strcpy(P_STOPB, d->stopb);
 	port_init();
 	mode_status();
   }
@@ -1203,6 +1314,8 @@ struct dialent *d;
 	port_init();
 	mode_status();
   }
+  else if (P_SHOWSPD[0] == 'l')
+    mode_status();
 
   /* Make sure the last date is updated   / jl 22.06.97 */
   writedialdir();
@@ -1221,23 +1334,38 @@ struct dialent *d;
 /*
  * Dial an entry from the dialing directory; this
  * is used for the "-d" command line flag.
+ * Now you can tag multiple entries with the -d option / jl 3.5.1999
  */
 void dialone(entry)
 char *entry;
 {
   int num;
   struct dialent *d;
+  struct dialent *d1 = (struct dialent *)NULL;
+  char *s;
   char buf[128];
 
-  /* Find entry. */
-  if ((num = atoi(entry)) != 0)
-	d = getno(num - 1);
-  else
-	for(d = dialents; d; d = d->next)
-		if (strstr(d->name, entry)) break;
+  s = strtok(entry,",;");
+  while (s) {
+    /* Find entry. */
+    if ((num = atoi(s)) != 0) {
+      d = getno(num - 1);
+      d->flags |= FL_TAG;
+      if (d1 == (struct dialent *)NULL)
+	d1 = d;
+    } else {
+      for(d = dialents; d; d = d->next)
+	if (strstr(d->name, s)) {
+	  d->flags |= FL_TAG;
+	  if (d1 == (struct dialent *)NULL)
+	    d1 = d;
+	}
+    }
+    s = strtok(NULL,",;");
+  }
 
   /* Not found. */
-  if (d == NULL) {
+  if (d1 == NULL) {
 	snprintf(buf, sizeof(buf), _("Entry \"%s\" not found. Enter dialdir?"), entry);
 	if (ask(buf, d_yesno) != 0) return;
 	dialdir();
@@ -1245,7 +1373,7 @@ char *entry;
   }
   /* Dial the number! */
   sleep(1);
-  dial_entry(d);
+  dial_entry(d1);
 }
 
 /*
@@ -1264,13 +1392,19 @@ void dialdir()
   int pgud = 0;
   int first = 1;
   int x1, x2;
-  char *s, dname[64];
-  static char manual[64];
+  char *s, dname[128];
+  static char manual[128];
   int changed = 0;
+  static char *tag_exit  = N_("( Escape to exit, Space to tag )"),
+    	      *move_exit = N_(" Move entry up/down, Escape to exit");
+  int tagmvlen = 0;
   int position_dialing_directory = ((COLS / 2) + 32 - strlen (_(what))) / 2;
 
   dprev = -1;
   dname[0] = 0;
+  tagmvlen = strlen(_(move_exit));
+  if (strlen(_(tag_exit)) > tagmvlen)
+	tagmvlen = strlen(_(tag_exit));
 
   /* Allright, draw the dialing directory! */
   
@@ -1292,7 +1426,7 @@ void dialdir()
 
   prdir(w, top, top);  
   wlocate(w, position_dialing_directory, w->ys - 1);
-  wputs(w, _("( Escape to exit, Space to tag )"));
+  wprintf(w, "%*.*s", tagmvlen,tagmvlen, _(tag_exit));
   dhili(position_dialing_directory, subm);
   dirflush = 1;
   wredraw(dsub, 1);
@@ -1317,11 +1451,11 @@ again:
   		case K_LT:
   		case 'h':
 			subm--;
-			if (subm < 0) subm = 5;
+			if (subm < 0) subm = DIALOPTS - 1;
   			break;
   		case K_RT:
   		case 'l':
-  			subm = (subm + 1) % 6;
+  			subm = (subm + 1) % DIALOPTS;
   			break;
   		case K_PGUP:
   		case '\002': /* Control-B */
@@ -1353,8 +1487,12 @@ again:
 			subm = 4;
 			quit = 1;
 			break;
+		case 'v':    /* moVe entry */
+		  	subm = 5;
+			quit = 2;
+			break;
 		case 'm':    /* Manual. */
-			subm = 5;
+			subm = 6;
 			quit = 1;
 			break;
 		case ' ':    /* Tag. */
@@ -1368,14 +1506,14 @@ again:
   		case '\033':
   		case '\r':
   		case '\n':
-  			quit = 1;
+  			quit = (subm==5 ? 2 : 1);
   			break;
   		default:
   			break;
   	}
   	/* Decide if we have to delete the cursor bar */
-  	if (cur != ocur || quit)
-	  wcurbar(w, ocur + 1 - top, XA_NORMAL | stdattr);
+  	if (cur != ocur || quit == 1)
+	  	wcurbar(w, ocur + 1 - top, XA_NORMAL | stdattr);
   		
   	if (cur < top) {
   		top--;
@@ -1452,7 +1590,7 @@ again:
   }
   /* Find an entry */
   if (subm == 1) {
-	s = input("Find an entry", dname);
+	s = input(_("Find an entry"), dname);
 	if (s == NULL || s[0] == 0) goto again;
 	x1 = 0;
 	for(d = dialents; d; d = d->next, x1++)
@@ -1538,16 +1676,31 @@ again:
 	}
   	ocur = cur;
   }
-  /* Dial a number manually. */
+
+  /* Move the entry up/down in directory. */
   if (subm == 5) {
+	wlocate(w, position_dialing_directory, w->ys - 1);
+	wprintf(w, "%*.*s", tagmvlen,tagmvlen, _(move_exit));
+	cur = move_entry (w, d, cur, &top);
+	if (cur != ocur)
+	  changed++;
+	ocur = cur;
+	wlocate(w, position_dialing_directory, w->ys - 1);
+	wprintf(w, "%*.*s", tagmvlen,tagmvlen, _(tag_exit));
+  }
+
+  /* Dial a number manually. */
+  if (subm == 6) {
 	s = input(_("Enter number"), manual);
 	if (s && *s) {
   		if (changed) writedialdir();
 		wclose(w, 1);
 		wclose(dsub, 1);
 		
-		strcpy(d_man->number, manual);
+		strncpy(d_man->number, manual, sizeof(d_man->number));
   		(void) dial(d_man, (struct dialent**)NULL);
+		if (P_SHOWSPD[0] == 'l')
+		  mode_status();
   		return;
 	}
   }
