@@ -240,7 +240,8 @@ size_t min_len;
 {
     void *vp;
 
-    vp = existing == NULL? malloc(min_len) : realloc(existing, min_len);
+    vp = existing == NULL? 
+      (void *)malloc(min_len) : (void *)realloc(existing, min_len);
 
     if(down_loading)
 	d_work_dir = vp;
@@ -450,7 +451,7 @@ init_filedir()
 	mbcolor, 0, 0, 1);
 
     if(ret_buf != NULL ||
-      (retstat = ((ret_buf = malloc(BUFSIZ)) == NULL)? -1 : 0) == 0) {
+      (retstat = ((ret_buf = (char *)malloc(BUFSIZ)) == NULL)? -1 : 0) == 0) {
 	retstat = new_filedir((GETSDIR_ENTRY *) NULL, 0);
 	dirflush = 1;
 	wredraw(dsub, 1);
@@ -500,7 +501,7 @@ GETSDIR_ENTRY *d;
 
     if(len) {
 	if(len > BUFSIZ) {
-	  if((ret_buf = realloc(ret_buf, len)) == NULL) {
+	  if((ret_buf = (char *)realloc(ret_buf, len)) == NULL) {
 	      file_tell(_("Too many files tagged - buffer would overflow"));
 	      return(NULL);
 	  }
