@@ -426,7 +426,7 @@ char *argv[];
 	exit(1);
     }
 
-    printf(_("%d files:\n"), cnt);
+    printf("%d files:\n", cnt);
     for(index = 1; index <= cnt; ++index, ++dirdat)
         printf("%2d: %-20s%s",
 	    index, dirdat->fname, ctime(&dirdat->time));
