@@ -15,9 +15,14 @@ then
 	exit 1
 fi
 
+for i in $*
+do
+	mkdir -p $i
+done
+
 if test ! -d $1
 then
-	mkdir $1
+	mkdir -p $1
 	if [ $? != 0 ]
 	then
 		echo "$1: No such directory"
