@@ -9,6 +9,9 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  *
+ *	When adding options, remember to add them here in the mpars structure
+ *	AND to the macro definitions in configsym.h.
+ *
  * // fmg 12/20/93 - kludged in color "support" (hey, it works)
  * // fmg 2/15/94 - added 9 x MAC_LEN char macros for F1 to F10 which can be
  *                  save to a specified file so that old defaults file
@@ -23,6 +26,8 @@
  * // jl  05.04.98 - added the multifile parameter for transfer protocols
  *    jl  06.07.98 - added option P_CONVCAP
  *    jl  28.11.98 - added P_SHOWSPD
+ *    jl  05.04.99 - logging options
+ *    er  18-Apr-99 - added P_MULTILINE for "multiline"
  */
 #include "port.h"
 #include "minicom.h"
@@ -99,6 +104,7 @@ struct pars mpars[] = {
   { DEF_BAUD,		PUBLIC,   "baudrate" },
   { "8",		PUBLIC,   "bits" },
   { "N",		PUBLIC,   "parity" },
+  { "1",		PUBLIC,   "stopbits" },
   /* Kermit the frog */
   { KERMIT,		PRIVATE,  "kermit" },
   { N_("Yes"),		PRIVATE,  "kermallow" },
@@ -168,6 +174,17 @@ struct pars mpars[] = {
   /* Do you want to be prompted for the download directory? */
   { "No",		PUBLIC,    "askdndir" },
 
+  /* Logfile options - jl 05.04.99 */
+#ifdef LOGFILE
+  { LOGFILE,		PUBLIC,    "logfname" },
+#else
+  { "/dev/null",	PUBLIC,    "logfname" },
+#endif
+  { "Yes",		PUBLIC,    "logconn" },
+  { "Yes",		PUBLIC,    "logxfer" },
+
+  { "No", 		PUBLIC,    "multiline"},
+
   /* That's all folks */
   { "",                 0,         (char *)NULL },
 };
