@@ -12,7 +12,7 @@
  *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg,
- *		1997-1998 Jukka Lahtinen
+ *		1997-1999 Jukka Lahtinen
  *
  *		This program is free software; you can redistribute it and/or
  *		modify it under the terms of the GNU General Public License
@@ -20,6 +20,7 @@
  *		2 of the License, or (at your option) any later version.
  *
  * 10.07.98 jl  Added the log command
+ * 05.04.99 jl  The logfile name should also be passed as a parameter
  */
 #include "port.h"
 #include "minicom.h"
@@ -31,7 +32,7 @@
 #define BREAK	2
 
 #ifndef lint
-char *Version = "@(#)runscript 1.22 10-Jul-1998 JL";
+char *Version = "@(#)runscript 1.23 31-May-1999 JL";
 #endif
 
 struct line {
@@ -77,6 +78,7 @@ char *s_pass = "password";	/* User's password */
 struct line *thisline;		/* Line to be executed */ 
 int laststatus = 0;		/* Status of last command */
 char homedir[256];		/* Home directory */
+char logfname[PARS_VAL_LEN];	/* Name of logfile */
 
 static char inbuf[65];		/* Input buffer. */
 
@@ -164,7 +166,7 @@ int dummy;
 		curenv->scriptname,"\r");
   	exit(1);
   }	
-  if (inexpect && etimeout && --etimeout == 0) longjmp(ejmp, 1);
+  if (inexpect && etimeout && --etimeout == 0) siglongjmp(ejmp, 1);
 }
 
 /*
@@ -532,7 +534,7 @@ char *text;
   		break;
 	}
   }
-  if (setjmp(ejmp) != 0) {
+  if (sigsetjmp(ejmp,1) != 0) {
   	f = s_exec(toact);
   	inexpect = 0;
   	return(f);
@@ -968,16 +970,21 @@ char **argv;
   memset(inbuf, 0, sizeof(inbuf));
 
   if (argc < 2) {
-  	s_error(_("Usage: runscript <scriptfile> [homedir]%s\n"),"\r");
-  	return(1);
+    s_error(_("Usage: runscript <scriptfile> [logfile [homedir]]%s\n"),"\r");
+    return(1);
   }
 
-  if (argc > 2)
-    strncpy(homedir, argv[2], sizeof(homedir));
-  else if ((s = getenv("HOME")) != CNULL)
-    strncpy(homedir, s, sizeof(homedir));
+  if (argc > 2) {
+    strncpy(logfname, argv[2], sizeof(logfname));
+    if (argc > 3)
+      strncpy(homedir, argv[3], sizeof(homedir));
+    else if ((s = getenv("HOME")) != CNULL)
+      strncpy(homedir, s, sizeof(homedir));
+    else
+      homedir[0]=0;
+  }
   else
-    homedir[0]=0;
+    logfname[0] = 0;
 
   return(execscript(argv[1]) != OK);
 }
