@@ -22,7 +22,7 @@
 _PROTO( void vt_install, (void(*)(), void (*)(), WIN *));
 _PROTO( void vt_init, (int, int, int, int, int));
 _PROTO( void vt_pinit, (WIN *, int, int));
-_PROTO( void vt_set, (int, int, FILE *, int, int, int, int));
+_PROTO( void vt_set, (int, int, FILE *, int, int, int, int, int));
 _PROTO( void vt_out, (int ));
 _PROTO( void vt_send, (int ch));
 
